EnrollCommonIcons class

Common icons shared across all flows.

Constructors

EnrollCommonIcons({EnrollBackgroundIcons? backgrounds, EnrollPopupIcons? popups, EnrollFieldIcons? fieldIcons, EnrollUiIcons? ui, EnrollStepIcon? termsAndConditions})
const

Properties

backgrounds EnrollBackgroundIcons?
final
fieldIcons EnrollFieldIcons?
final
hashCode int
The hash code for this object.
no setterinherited
popups EnrollPopupIcons?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
termsAndConditions EnrollStepIcon?
final
ui EnrollUiIcons?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited