EnrollFieldIcons class

Profile / data display field icons.

Constructors

EnrollFieldIcons({EnrollStepIcon? user, EnrollStepIcon? calendar, EnrollStepIcon? gender, EnrollStepIcon? issuingAuthority, EnrollStepIcon? nationality, EnrollStepIcon? num, EnrollStepIcon? passport, EnrollStepIcon? address, EnrollStepIcon? idCard, EnrollStepIcon? profession, EnrollStepIcon? religion, EnrollStepIcon? maritalStatus})
const

Properties

address EnrollStepIcon?
final
calendar EnrollStepIcon?
final
gender EnrollStepIcon?
final
hashCode int
The hash code for this object.
no setterinherited
idCard EnrollStepIcon?
final
issuingAuthority EnrollStepIcon?
final
maritalStatus EnrollStepIcon?
final
nationality EnrollStepIcon?
final
num EnrollStepIcon?
final
passport EnrollStepIcon?
final
profession EnrollStepIcon?
final
religion EnrollStepIcon?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user EnrollStepIcon?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited