EnrollForgetIcons class

Icons shown in the Forget Profile Data step-list screen.

Constructors

EnrollForgetIcons({EnrollStepIcon? modeIcon, EnrollStepIcon? nationalId, EnrollStepIcon? passport, EnrollStepIcon? phone, EnrollStepIcon? email, EnrollStepIcon? device, EnrollStepIcon? location, EnrollStepIcon? securityQuestions, EnrollStepIcon? password})
const

Properties

device EnrollStepIcon?
final
email EnrollStepIcon?
final
hashCode int
The hash code for this object.
no setterinherited
location EnrollStepIcon?
final
modeIcon EnrollStepIcon?
final
nationalId EnrollStepIcon?
final
passport EnrollStepIcon?
final
password EnrollStepIcon?
final
phone EnrollStepIcon?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityQuestions EnrollStepIcon?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited