EnrollUpdateIcons class

Icons shown in the Update step-list screen.

Constructors

EnrollUpdateIcons({EnrollStepIcon? modeIcon, EnrollStepIcon? idCard, EnrollStepIcon? passport, EnrollStepIcon? mobile, EnrollStepIcon? email, EnrollStepIcon? device, EnrollStepIcon? address, EnrollStepIcon? securityQuestions, EnrollStepIcon? password})
const

Properties

address EnrollStepIcon?
final
device EnrollStepIcon?
final
email EnrollStepIcon?
final
hashCode int
The hash code for this object.
no setterinherited
idCard EnrollStepIcon?
final
mobile EnrollStepIcon?
final
modeIcon EnrollStepIcon?
final
passport EnrollStepIcon?
final
password EnrollStepIcon?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityQuestions EnrollStepIcon?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited