EnrollFontSizes enum

Predefined font-size presets supported by the native SDKs.

The native iOS EnrollFontSizes is now initialized with one of three presets instead of individual per-style sizes. Mirror that here.

Note: default is a reserved word in Dart, so the enum value is named EnrollFontSizes.defaultSize but serialized as the string "default".

Inheritance
Available extensions

Values

defaultSize → const EnrollFontSizes
medium → const EnrollFontSizes
large → const EnrollFontSizes

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Wire format expected by the native bridges.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EnrollFontSizes>
A constant List of the values in this enum, in order of their declaration.