EnrollTextStyle enum

Logical text styles used by the SDK. Provided here purely as a reference for consumers; not serialized over the method channel.

Inheritance
Available extensions

Values

title → const EnrollTextStyle
subTitle → const EnrollTextStyle
body → const EnrollTextStyle
button → const EnrollTextStyle
input → const EnrollTextStyle

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EnrollTextStyle>
A constant List of the values in this enum, in order of their declaration.