EnrollBackgroundIcons class
Background images used across screens.
Constructors
- EnrollBackgroundIcons({EnrollStepIcon? main, EnrollStepIcon? layer1, EnrollStepIcon? layer2, EnrollStepIcon? layer3, EnrollStepIcon? blur, EnrollStepIcon? header, })
-
const
Properties
- blur → EnrollStepIcon?
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → EnrollStepIcon?
-
final
- layer1 → EnrollStepIcon?
-
final
- layer2 → EnrollStepIcon?
-
final
- layer3 → EnrollStepIcon?
-
final
- main → EnrollStepIcon?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited