EnrollIcons class
Top-level icon configuration for the eNROLL SDK.
All fields are optional — when null, the SDK uses its built-in assets.
Example:
EnrollIcons(
logo: EnrollLogoConfig(
mode: EnrollLogoMode.custom,
assetName: 'my_company_logo',
renderingMode: EnrollIconRenderingMode.original,
),
location: EnrollLocationIcons(
tutorial: EnrollStepIcon(assetName: 'my_location_tutorial'),
),
)
Constructors
- EnrollIcons({EnrollLogoConfig? logo, EnrollLocationIcons? location, EnrollNationalIdIcons? nationalId, EnrollPassportIcons? passport, EnrollPhoneIcons? phone, EnrollEmailIcons? email, EnrollFaceMatchingIcons? faceMatching, EnrollSecurityQuestionsIcons? securityQuestions, EnrollPasswordIcons? password, EnrollSignatureIcons? signature, EnrollCommonIcons? common, EnrollUpdateIcons? update, EnrollForgetIcons? forget})
-
const
Properties
- common → EnrollCommonIcons?
-
final
- email → EnrollEmailIcons?
-
final
- faceMatching → EnrollFaceMatchingIcons?
-
final
- forget → EnrollForgetIcons?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- location → EnrollLocationIcons?
-
final
- logo → EnrollLogoConfig?
-
final
- nationalId → EnrollNationalIdIcons?
-
final
- passport → EnrollPassportIcons?
-
final
- password → EnrollPasswordIcons?
-
final
- phone → EnrollPhoneIcons?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- securityQuestions → EnrollSecurityQuestionsIcons?
-
final
- signature → EnrollSignatureIcons?
-
final
- update → EnrollUpdateIcons?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited