EnrollLocationIcons class
Icons for the Location step.
Constructors
- EnrollLocationIcons({EnrollStepIcon? tutorial, EnrollStepIcon? requestAccess, EnrollStepIcon? accessError, EnrollStepIcon? grab})
-
const
Properties
- accessError → EnrollStepIcon?
-
final
- grab → EnrollStepIcon?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestAccess → EnrollStepIcon?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tutorial → EnrollStepIcon?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited