EnrollLogoConfig class

Configuration for the SDK logo on splash screens and the app bar.

Constructors

EnrollLogoConfig({EnrollLogoMode mode = EnrollLogoMode.defaultLogo, String? assetName, EnrollIconRenderingMode renderingMode = EnrollIconRenderingMode.original})
const

Properties

assetName String?
The Android drawable resource name for the custom logo. Required when mode is EnrollLogoMode.custom.
final
hashCode int
The hash code for this object.
no setterinherited
mode EnrollLogoMode
How the logo should be displayed.
final
renderingMode EnrollIconRenderingMode
How the logo should be rendered.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited