EnrollPhoneIcons class
Icons for the Phone OTP step.
Constructors
- EnrollPhoneIcons({EnrollStepIcon? tutorial, EnrollStepIcon? select, EnrollStepIcon? validateOtp})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- select → EnrollStepIcon?
-
final
- tutorial → EnrollStepIcon?
-
final
- validateOtp → EnrollStepIcon?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited